pub struct InboundTlsSection {
pub cert_path: PathBuf,
pub key_path: PathBuf,
/* private fields */
}Expand description
Inbound server identity loaded and validated before binding a listener.
Fields
cert_path: PathBufPath to the PEM-encoded certificate chain.
key_path: PathBufPath to the PEM-encoded private key.
Implementations
Sourceimpl InboundTlsSection
impl InboundTlsSection
Sourcepub fn from_paths(cert_path: PathBuf, key_path: PathBuf) -> Self
pub fn from_paths(cert_path: PathBuf, key_path: PathBuf) -> Self
Construct an inbound identity whose absolute or caller-owned paths are read when the transport identity is loaded.