pub struct RolePlayerSpec {
pub role: String,
pub entity_type: String,
pub iid: Option<String>,
pub key_attr: Option<String>,
pub key_value: Option<AttributeValueSpec>,
}Expand description
Specification for a role player in a relation insert.
Fields
role: StringThe role name (e.g. “employee”, “employer”).
entity_type: StringThe entity type of the role player.
iid: Option<String>Optional IID to identify the role player directly.
key_attr: Option<String>Optional key attribute name to find the role player by.
key_value: Option<AttributeValueSpec>Optional key attribute value to find the role player by.